@@ -16,5 +16,5 @@ def init_nng_threads(task=2, expire=1, poller=1, resolver=1):
         lib.nng_init_set_parameter(lib.NNG_INIT_NUM_EXPIRE_THREADS, expire)
         lib.nng_init_set_parameter(lib.NNG_INIT_NUM_POLLER_THREADS, poller)
         lib.nng_init_set_parameter(lib.NNG_INIT_NUM_RESOLVER_THREADS, resolver)
-    except:
-        logger.error(f"[INIT-THREADS] Interface is not avaliable")
+    except AttributeError:
+        logger.error("[INIT-THREADS] Cannot adjust thread count: interface unavailable")
\ No newline at end of file
